<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="zh_TW">
<context>
    <name>AuthDialog</name>
    <message>
        <location filename="../AuthDialog.cpp" line="72"/>
        <source>Finger moved too fast, please do not lift until prompted</source>
        <translation>接觸時間短，驗證時請勿移動手指</translation>
    </message>
    <message>
        <location filename="../AuthDialog.cpp" line="74"/>
        <source>Verification failed, two chances left</source>
        <translation>驗證失敗，您還可以嘗試2次</translation>
    </message>
    <message>
        <location filename="../AuthDialog.cpp" line="90"/>
        <location filename="../AuthDialog.cpp" line="327"/>
        <source>Confirm</source>
        <comment>button</comment>
        <translation>確 定</translation>
    </message>
    <message>
        <location filename="../AuthDialog.cpp" line="159"/>
        <source>Expired</source>
        <translation>已過期</translation>
    </message>
    <message>
        <location filename="../AuthDialog.cpp" line="248"/>
        <source>Unavailable</source>
        <translation>不可用</translation>
    </message>
    <message>
        <location filename="../AuthDialog.cpp" line="250"/>
        <source>The password of this user has expired. Please authenticate using another user account or change the password and try again.</source>
        <translation>此帳號密碼已過期，請使用其他帳號鑒權或者修改此帳號密碼後再嘗試</translation>
    </message>
    <message>
        <location filename="../AuthDialog.cpp" line="287"/>
        <source>Locked, please try again later</source>
        <translation>已鎖定，請稍後再試</translation>
    </message>
    <message>
        <location filename="../AuthDialog.cpp" line="289"/>
        <source>Wrong password</source>
        <translation>密碼錯誤</translation>
    </message>
    <message>
        <location filename="../AuthDialog.cpp" line="326"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>取 消</translation>
    </message>
</context>
</TS>